Scores — skchange

Skip to main content
`Ctrl`+`K`

# Scores

`score_factory`([score]) | Return score function and its initializer.
`init_mean_score`(X) | Precompute sums for mean_score.
`mean_score`(precomputed_params, starts, ends, ...) | Calculate the CUSUM score for a change in the mean.
`mean_anomaly_score`(precomputed_params, ...) | Calculate the CUSUM score for difference in the mean of a subinterval.
`init_mean_var_score`(X) | Precompute sums and squared sums for mean_var_score.
`mean_var_score`(precomputed_params, starts, ...) | Calculate the score for a change in the mean and/or variance.
`mean_var_anomaly_score`(precomputed_params, ...) | Calculate the score for an anomaly in the mean and/or variance.
`init_mean_cov_score`(X) | Precompute quantities for the mean_cov_score.
`mean_cov_score`(precomputed_params, starts, ...) | Calculate likelihood ratio scores for a change in mean and covariance [R06523a6da177-1].